@@ -3,6 +3,8 @@ import os.path
 import hashlib
 
 from blah.util import run
+import blah.caching
+
 
 class Git(object):
     name = "git"
@@ -32,16 +34,16 @@ class Git(object):
         return GitRepository(working_directory)
         
     def _update_cache(self, repository_uri):
-        cache_dir = os.environ.get("BLAH_CACHE_DIR", os.path.expanduser("~/.cache/blah"))
+        cache_root = blah.caching.cache_root()
         repo_hash = hashlib.sha1(repository_uri).hexdigest()
-        cache_repo = os.path.join(cache_dir, repo_hash)
+        cache_dir = os.path.join(cache_root, repo_hash)
         
-        if os.path.exists(cache_repo):
-            _git(["fetch"], cwd=cache_repo)
+        if os.path.exists(cache_dir):
+            _git(["fetch"], cwd=cache_dir)
         else:
-            _git(["clone", repository_uri, cache_repo])
+            _git(["clone", repository_uri, cache_dir])
             
-        return cache_repo
+        return cache_dir
 
 class GitRepository(object):
     type = Git.name
@@ -63,6 +65,15 @@ class GitRepository(object):
         
     def head_revision(self):
         return _git(["rev-parse", "HEAD"], cwd=self.working_directory).output.strip()
+        
+    def is_fixed_revision(self, revision):
+        if revision is None:
+            return False
+        else:
+            return self._is_tag(revision)
+        
+    def _is_tag(self, revision):
+        return bool(_git(["tag", "--list", revision], cwd=self.working_directory).output.strip())
 
 def _git(git_command, *args, **kwargs):
     command = ["git"] + git_command
